@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1353 2021/12/05 19:58:12 jca Exp $
+# $OpenBSD: Quirks.pm,v 1.1381 2022/03/29 18:31:13 sdk Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -341,7 +341,6 @@ my $stem_extensions = {
 	'py-unicodecsv' => 'py3-unicodecsv',
 	'py-enchant' => 'py3-enchant',
 	'py-sqlparse' => 'py3-sqlparse',
-	'py-sqlalchemy-migrate' => 'py3-sqlalchemy-migrate',
 	'py-pygresql' => 'py3-pygresql',
 	'py-tagpy' => 'py3-tagpy',
 	'py-mpd2' => 'py3-mpd2',
@@ -640,7 +639,6 @@ my $stem_extensions = {
 	'py-olefile' => 'py3-olefile',
 	'py-pandocfilters' => 'py3-pandocfilters',
 	'py-parallel' => 'py3-parallel',
-	'py-pathlib' => 'py3-pathlib',
 	'py-pathspec' => 'py3-pathspec',
 	'py-pbkdf2' => 'py3-pbkdf2',
 	'py-peewee' => 'py3-peewee',
@@ -694,6 +692,34 @@ my $stem_extensions = {
 	'apertium-mk-bg' => 'apertium-mkd-bul',
 	'apertium-mk-en' => 'apertium-mkd-eng',
 	'apertium-pt-ca' => 'apertium-por-cat',
+	'pinentry-gtk2' => 'pinentry-gnome3',
+	'sxiv' => 'nsxiv',
+	'geoclue' => 'geoclue2',
+	'py-extras' => 'py3-extras',
+	'py-fixtures' => 'py3-fixtures',
+	'py-pbr' => 'py3-pbr',
+	'py-testtools' => 'py3-testtools',
+	'py-pyusb' => 'py3-pyusb',
+	'py-atomicwrites' => 'py3-atomicwrites',
+	'py-attrs' => 'py3-attrs',
+	'py-coverage' => 'py3-coverage',
+	'py-dateutil' => 'py3-dateutil',
+	'py-freezegun' => 'py3-freezegun',
+	'py-hypothesis' => 'py3-hypothesis',
+	'py-more-itertools' => 'py3-more-itertools',
+	'py-pluggy' => 'py3-pluggy',
+	'py-py' => 'py3-py',
+	'py-test' => 'py3-test',
+	'py-test-benchmark' => 'py3-test-benchmark',
+	'py-test-cov' => 'py3-test-cov',
+	'py-test-mock' => 'py3-test-mock',
+	'py-test-runner' => 'py3-test-runner',
+	'py-setuptools_scm' => 'py3-setuptools_scm',
+	'ssvnc-viewer' => 'tigervnc',
+	'py-tz' => 'py3-tz',
+	'py-pretend' => 'py3-pretend',
+	'py-mock' => 'py3-mock',
+	'gmic-qt-krita' => 'krita-gmic-plugin',
 };
 
 my $obsolete_reason = {};
@@ -725,7 +751,6 @@ setup_obsolete_reason(
 	3 => 'telepathy-qt',
 	3 => 'telepathy-farstream',
 	3 => 'farstream',
-	6 => 'libnice',
 	5 => 'ardour',
 	5 => 'aubio',
 	5 => 'liblo',
@@ -794,7 +819,6 @@ setup_obsolete_reason(
 	3 => 'py3-crypto',
 	5 => 'tremor',
 	5 => 'tremor-tools',
-	3 => 'xtrkcad',
 	2 => 'webkit',
 	5 => 'py-test-capturelog',
 	5 => 'py3-test-capturelog',
@@ -1079,8 +1103,6 @@ setup_obsolete_reason(
 	3 => 'py-vatnumber',
 	6 => 'nap',
 	5 => 'qucs',
-	1 => 'py-arrow',
-	1 => 'py3-arrow',
 	1 => 'py-chai',
 	1 => 'py3-chai',
 	1 => 'py-binaryornot',
@@ -1528,6 +1550,7 @@ setup_obsolete_reason(
 	13 => 'gmapcatcher',
 	3 => 'childsplay',
 	6 => 'py-texscythe',
+	6 => 'py-sqlalchemy-migrate',
 	6 => 'py3-sqlalchemy-migrate',
 	13 => 'rawdog',
 	13 => 'charm',
@@ -1622,6 +1645,23 @@ setup_obsolete_reason(
 	5 => 'ocaml-biniou',
 	5 => 'ocaml-easy-format',
 	5 => 'libdsm',
+	45 => 'direvent',
+	3 => 'climm',
+	31 => 'spe',
+	31 => 'py-Checker',
+	14 => 'ssvnc',
+	11 => 'netshot',
+	31 => 'py-contextlib2',
+	31 => 'py-linecache2',
+	31 => 'py-traceback2',
+	31 => 'py-unittest2',
+	31 => 'py-pathlib',
+	31 => 'py-pathlib2',
+	6 => 'py3-pathlib',
+	6 => 'py3-pathlib2',
+	31 => 'py-ipaddress',
+	31 => 'py-scandir',
+	3 => 'd-feet',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1656,13 +1696,14 @@ my $obsolete_message = {
 	11 => "no longer packageable",
 	12 => "replace with IMAPSieve, see https://wiki.dovecot.org/HowTo/AntispamWithSieve",
 	13 => "has a dependency on obsolete software",
+	14 => "no longer maintained upstream and has security issues, consider remmina or tigervnc's vncviewer as an alternative",
 	17 => "old GeoIP databases end-of-life, see alternative using geoip2/libmaxminddb",
 	20 => "merged into IETF Opus codec, obsolete, audio/mumble uses bundled version now",
 	21 => "upstream recommends to use composer to build a drupal site",
 	22 => "the original GeoIP database is end of life; use libmaxminddb/GeoIP2",
 	23 => "no longer maintained upstream, became commercial over ten years ago",
 	26 => "outdated Qt4 application",
-	27 => "requires GUdev or GUsb",
+	27 => "requires GUdev",
 	28 => "consider migrating MCollective agents and filters using tools like Bolt and PuppetDB's Puppet Query Language",
 	29 => "unmaintained port that was blocking other changes in ports",
 	30 => "crashes in many different ways at runtime, does not build with '-fno-common'",
@@ -1678,6 +1719,7 @@ my $obsolete_message = {
 	41 => "upstream moved to unversioned tarballs, use the plan9port (same upstream) package instead",
 	43 => "using portgen instead is recommended",
 	44 => "qucs-s Qt4 UI not working correctly, suggest xschem or kicad's eeschema instead",
+	45 => "crashes in many different ways at runtime",
 };
 
 # ->is_base_system($handle, $state):
@@ -1831,6 +1873,7 @@ my $cve = {
 	'net/libssh' => 'libssh-<0.9.5',
 	'net/libssh2' => 'libssh2-<1.8.2',
 	'net/lldpd' => 'lldpd-<0.7.18p0',
+	'net/miniupnp/miniupnpd' => 'miniupnpd-<2.3.0',
 	'net/mosquitto' => 'mosquitto-<1.5.6',
 	'net/ntp' => 'ntp-<4.2.8pl7',
 	'net/openconnect' => 'openconnect-<8.10',
@@ -1856,7 +1899,7 @@ my $cve = {
 	'security/libssh' => 'libssh-<0.9.4',
 	'security/opensc' => 'opensc-<0.20.0',
 	'security/openssl/1.1' => 'openssl-<1.1.1g',
-	'security/polarssl' => 'mbedtls-<2.16.6',
+	'security/polarssl' => 'mbedtls-<2.16.12',
 	'security/sudo' => 'sudo-<1.8.31',
 	'shells/bash' => 'bash-<4.3.27',
 	'sysutils/ansible,-main' => 'ansible-<2.7.1',
